Simulator

Struct Simulator 

pub struct Simulator<H: PublishHook = NoOpHook> { /* private fields */ }

Implementations

Source

impl Simulator<NoOpHook>

pub fn new( subscribers: HashMap<String, Box<dyn Subscriber>>, initial_time: SystemTime, initial_events: Vec<Vec<SimulatorEvent>>, ) -> Self

Creates a new simulator with the given subscribers, initial time, and initial events.

The number of queues is determined by the length of the initial_events vector, and this must match the number of queues in a crate::message_bus::MessageBus to accurately simulate the message bus.

Source

impl<H: PublishHook> Simulator<H>

pub fn with_hook( subscribers: HashMap<String, Box<dyn Subscriber>>, initial_time: SystemTime, initial_events: Vec<Vec<SimulatorEvent>>, hook: H, ) -> Self

Creates a new simulator with the given subscribers, initial time, initial events, and publish hook.

The number of queues is determined by the length of the initial_events vector, and this must match the number of queues in a crate::message_bus::MessageBus to accurately simulate the message bus.

pub fn step(&mut self, step_by: Duration) -> SystemTime

Steps the simluator by some duration, looping through all of the subscribers to process events from the queue, then run their tick.

Returns the new time after the step.

pub fn step_to(&mut self, time: SystemTime, step_by: Duration) -> SystemTime